@@ -13,7 +13,8 @@
 #' @param pat scale of provided event rates (per `pat`-years).
 #' @param shape shape of the Weibull distribution for time-to-event outcomes. Default is exponential distribution with `shape = 1`.
 #' @param logC logical, whether to use log-normal distribution for the continuous outcome.
-#' @param seed the seed for generating random numbers.
+#' @param seed for generating random numbers.
+#' @param dec decimal places for the continuous outcome used for rounding. The default is `dec = 2`.
 #' @return an object of class `hce` containing the following columns:
 #' * ID subject identifier.
 #' * TRTP planned treatment group - "A" for active, "P" for Placebo.
@@ -27,7 +28,7 @@
 #' * PADY primary analysis day, the length of fixed follow-up in days calculated as `yeardays` multiplied by `fixedfy`.
 #' @export
 #' @md
-#' @seealso [hce::hce()], [hce::as_hce()] for the helper a coerce function to hce objects.
+#' @seealso [hce::hce()], [hce::as_hce()] for the helper a coerce function to `hce` objects.
 #' @examples
 #' # Example 1
 #' Rates_A <- c(1.72, 1.74, 0.58, 1.5, 1)
@@ -40,10 +41,10 @@
 #' Rates_A <- 10
 #' Rates_P <- 15
 #' dat <- simHCE(n = 1000, n0 = 500, TTE_A = Rates_A, TTE_P = Rates_P, 
-#'               CM_A = 0.1, CM_P = 0, seed = 5, shape = 0.2, logC = TRUE)
+#'               CM_A = 0.1, CM_P = 0, seed = 5, shape = 0.2, logC = TRUE, dec = 0)
 #' summaryWO(dat)
 
-simHCE <- function(n, n0 = n, TTE_A, TTE_P, CM_A, CM_P, CSD_A = 1, CSD_P = 1, fixedfy = 1, yeardays = 360, pat = 100, shape = 1, logC = FALSE, seed = NULL ){
+simHCE <- function(n, n0 = n, TTE_A, TTE_P, CM_A, CM_P, CSD_A = 1, CSD_P = CSD_A, fixedfy = 1, yeardays = 360, pat = 100, shape = 1, logC = FALSE, seed = NULL, dec = 2 ){
   if(base::length(TTE_P) != base::length(TTE_A))
     stop("Event rate vectors for active and placebo groups should have the same length")
   
@@ -59,6 +60,7 @@ simHCE <- function(n, n0 = n, TTE_A, TTE_P, CM_A, CM_P, CSD_A = 1, CSD_P = 1, fi
   seed <- seed[1]
   logC <- as.logical(logC[1])
   shape <- shape[1]
+  dec <- dec[1]
 
   fixedf <- yeardays*fixedfy
   TTE_P <- TTE_P/yeardays/pat
@@ -101,32 +103,25 @@ simHCE <- function(n, n0 = n, TTE_A, TTE_P, CM_A, CM_P, CSD_A = 1, CSD_P = 1, fi
   dat$GROUP <- base::as.character(dat$EVENT)
   dat$GROUPN <- dat$EVENTN*dat$PADY
 
-  lencont_A <- dat$GROUP=="C" & dat$TRTP=="A"
-  lencont_P <- dat$GROUP=="C" & dat$TRTP=="P"
+  lXA <- round(stats::rlnorm(n, meanlog = CM_A, sdlog = CSD_A), dec)
+  lXP <- round(stats::rlnorm(n0, meanlog = CM_P, sdlog = CSD_P), dec)
+  XA <- round(stats::rnorm(n, mean = CM_A, sd = CSD_A), dec)
+  XP <- round(stats::rnorm(n0, mean = CM_P, sd = CSD_P), dec)
   
-
-  if(logC){
-    dat[lencont_A, "AVAL0"] <- round(stats::rlnorm(base::sum(lencont_A), 
-                                                   meanlog = CM_A, sdlog = CSD_A), 2)
-    dat[lencont_P, "AVAL0"] <- round(stats::rlnorm(base::sum(lencont_P), 
-                                                   meanlog = CM_P, sdlog = CSD_P), 2)
+  if(logC) {
+    dat[dat$TRTP == "A", "AVAL0"] <- lXA
+    dat[dat$TRTP == "P", "AVAL0"] <- lXP
   } else {
-    dat[lencont_A, "AVAL0"] <- round(stats::rnorm(base::sum(lencont_A), 
-                                                  mean = CM_A, sd = CSD_A), 2)
-    dat[lencont_P, "AVAL0"] <- round(stats::rnorm(base::sum(lencont_P), 
-                                                  mean = CM_P, sd = CSD_P), 2)
+    dat[dat$TRTP == "A", "AVAL0"] <- XA
+    dat[dat$TRTP == "P", "AVAL0"] <- XP
   }
-  
-  dat[base::is.na(dat$AVAL0), "AVAL0"] <- dat[base::is.na(dat$AVAL0), "AVALT"]
+  dat[dat$GROUP != "C", "AVAL0"] <- dat[dat$GROUP != "C", "AVALT"]
   mcont <- min(dat[dat$GROUP == "C", "AVAL0"])
   dat$AVAL <- ifelse(dat$GROUP != "C", dat$AVAL0 + dat$GROUPN, dat$AVAL0 - mcont + 1 + dat$GROUPN)
-
-  dat <- dat[ , c("ID", "TRTP", "GROUP", "GROUPN", "AVALT", "AVAL0", "AVAL", "seed")]
+  dat <- dat[, c("ID", "TRTP", "GROUP", "GROUPN", "AVALT", "AVAL0", "AVAL", "seed")]
   dat$PADY <- fixedf
-  
   dat <- as_hce(dat)
   return(dat)
-
 }
 
 
